<?php

/***************************************************************
*
* Sitemap-Plugin für moziloCMS.
* 
* Details: http://software.azett.com
* 
***************************************************************/

class Sitemap extends Plugin {

    /***************************************************************
    * 
    * Gibt den HTML-Code zurück, mit dem die Plugin-Variable ersetzt 
    * wird. Der String-Parameter $value ist Pflicht, kann aber leer 
    * sein.
    * 
    ***************************************************************/
    function getContent($value) {
        global $specialchars;
        $category = null;
        if ($value != null) {
            $category = nameToCategory($specialchars->replaceSpecialChars($specialchars->getHtmlEntityDecode($value),false));
        }
        $sitemapinfo = $this->getSitemapContent($category);
        return $sitemapinfo[0];
    } // function getContent
    
    
    
    /***************************************************************
    * 
    * Gibt die Konfigurationsoptionen als Array zurück.
    * Ist keine Konfiguration nötig, gibt die Funktion false zurück.
    * 
    ***************************************************************/
    function getConfig() {
        global $ADMIN_CONF;
        $language = $ADMIN_CONF->get("language");

        $config = array(); // keine Konfiguration nötig
        $config['deDE']['showcatnames'] = array(
            "type" => "checkbox",                       // Pflicht:  Eingabetyp 
            "description" => "Kategorienamen anzeigen?"            // Pflicht:  Beschreibung
        );
        $config['enEN']['showcatnames'] = array(
            "type" => "checkbox",                       // Pflicht:  Eingabetyp 
            "description" => "Show category names?"            // Pflicht:  Beschreibung
        );

        // Jetzt wird das Optionen-Array in der aktuell verwendeten Sprache zurückgegeben. 
        if(isset($config[$language])) {
            return $config[$language];
        }
        // Stellt das Plugin diese Sprache nicht zur Verfügung, werden die englischen Optionen zurückgegeben.
        else {
            return $config['enEN'];
        }
    } // function getConfig
    
    
    
    /***************************************************************
    * 
    * Gibt die Plugin-Infos als Array zurück - in dieser 
    * Reihenfolge:
    *   - Name des Plugins
    *   - Version des Plugins
    *   - Kurzbeschreibung
    *   - Name des Autors
    *   - Download-URL
    * 
    ***************************************************************/
    function getInfo() {
        global $ADMIN_CONF;
        $language = $ADMIN_CONF->get("language");

        $info = array();
        $info['deDE'] = array(
            // Plugin-Name + Version
            "<b>Sitemap</b> 1.0.2010-10-13",
            // moziloCMS-Version
            "1.12",
            // Kurzbeschreibung nur <span> und <br /> sind erlaubt
            "Standard-Sitemap zum Einfügen an beliebiger Stelle<br /><br />Nutzung:<br />{Sitemap} für Gesamt-Sitemap<br />{Sitemap|Kategorie} für Sitemap einer Kategorie",
            // Name des Autors
            "Arvid Zimmermann",
            // Download-URL
            "http://software.azett.com",
            // Platzhalter für die Selectbox in der Editieransicht 
            // - ist das Array leer, erscheint das Plugin nicht in der Selectbox
            array(
                '{Sitemap}' => 'Gesamt-Sitemap',
                '{Sitemap|}' => 'Sitemap einer Kategorie'
            )
        );
        $info['enEN'] = array(
            // Plugin-Name + Version
            "<b>Sitemap</b> 1.0.2010-09-14",
            // moziloCMS-Version
            "1.12",
            // Kurzbeschreibung nur <span> und <br /> sind erlaubt
            "Standard sitemap to use everywhere<br /><br />Usage:<br />{Sitemap} for overall sitemap<br />{Sitemap|Category} for sitemap of one category",
            // Name des Autors
            "Arvid Zimmermann",
            // Download-URL
            "http://software.azett.com",
            // Platzhalter für die Selectbox in der Editieransicht 
            // - ist das Array leer, erscheint das Plugin nicht in der Selectbox
            array(
                '{Sitemap}' => 'Overall sitemap',
                '{Sitemap|}' => 'Sitemap of one category'
            )
        );
        // Jetzt wird das Optionen-Array in der aktuell verwendeten Sprache zurückgegeben. 
        if(isset($info[$language])) {
            return $info[$language];
        }
        // Stellt das Plugin diese Sprache nicht zur Verfügung, werden die englischen Optionen zurückgegeben.
        else {
            return $info['enEN'];
        }
    } // function getInfo
    
    /*
        Sitemap-Inhalt zusammenbauen und zurückgeben
        (kopiert aus der index.php-Funktion getSiteMap() und angepaßt)
    */
    function getSitemapContent($category) {
        global $CONTENT_DIR_REL;
        global $language;
        global $specialchars;
        global $CMS_CONF;
        global $EXT_LINK;
        global $URL_BASE;
        
        $showhiddenpages = ($CMS_CONF->get("showhiddenpagesinsitemap") == "true");
        
        $sitemap = "<div class=\"sitemap\">";
        // Kategorien-Verzeichnis einlesen
        $categoriesarray = getDirContentAsArray($CONTENT_DIR_REL, false, false);
        // Jedes Element des Arrays an die Sitemap anhaengen
        foreach ($categoriesarray as $currentcategory) {
            // Wenn eine bestimmte Kategorie übergeben wurde und das nicht die aktuelle Kategorie ist:
            if (($category != null) && ($currentcategory != $category)) {
                // weiter zur nächsten Kategorie!
                continue;
            }
            // Wenn die Kategorie keine Contentseiten hat, zeige sie nicht an
            $contentarray = getDirContentAsArray($CONTENT_DIR_REL.$currentcategory, true, $showhiddenpages);
            if ($contentarray == "")
                continue;

            // Kategorienamen nur zeigen, wenn konfiguriert
            if ($this->settings->get("showcatnames") == "true") {
                $sitemap .= "<h2>".catToName($currentcategory, false)."</h2>";
            }
            $sitemap .= "<ul>";
            // Alle Inhaltsseiten der aktuellen Kategorie auflisten...
            // Jedes Element des Arrays an die Sitemap anhaengen
            foreach ($contentarray as $currentcontent) {
                # ist ein link
                if(substr($currentcontent,-(strlen($EXT_LINK))) == $EXT_LINK) {
                    continue;
                }
                $url = "index.php?cat=".substr($currentcategory,3)."&amp;page=".substr($currentcontent, 3, strlen($currentcontent) - 7);
                if($CMS_CONF->get("modrewrite") == "true") {
                    $url = $URL_BASE.substr($currentcategory,3)."/".substr($currentcontent, 3, strlen($currentcontent) - 7).".html";
                }
                $sitemap .= "<li><a href=\"$url\"".getTitleAttribute($language->getLanguageValue2("tooltip_link_page_2", pageToName($currentcontent, false), catToName($currentcategory, false))).">".
                                                    pageToName($currentcontent, false).
                                                    "</a></li>";
            }
            $sitemap .= "</ul>";
        }
        $sitemap .= "</div>";
        // Rueckgabe der Sitemap
        return array($sitemap, $language->getLanguageValue0("message_sitemap_0"), $language->getLanguageValue0("message_sitemap_0"));
    }

} // class Sitemap

    
?>